pub struct Post {Show 23 fields
pub height: NonZeroU64,
pub score: i64,
pub file_url: Url,
pub parent_id: Option<NonZeroU64>,
pub sample_url: Url,
pub sample_width: NonZeroU64,
pub sample_height: NonZeroU64,
pub preview_url: Url,
pub rating: Rating,
pub tags: Box<str>,
pub id: NonZeroU64,
pub width: NonZeroU64,
pub change: OffsetDateTime,
pub md5: Md5Digest,
pub creator_id: NonZeroU64,
pub has_children: bool,
pub created_at: OffsetDateTime,
pub status: PostStatus,
pub source: Option<Box<str>>,
pub has_notes: bool,
pub has_comments: bool,
pub preview_width: NonZeroU64,
pub preview_height: NonZeroU64,
}Expand description
A Post
Fields
height: NonZeroU64The height of the original file.
score: i64The number of up-votes minus the number of down-votes.
file_url: UrlThe main file url
parent_id: Option<NonZeroU64>The parent post id
sample_url: UrlThe sample url
sample_width: NonZeroU64The sample width
sample_height: NonZeroU64The sample height
preview_url: UrlThe preview url
rating: RatingThe image rating
A list of tag names.
Tag names are separated by one or more spaces. There may or may not be a leading or trailing space. Tag names are always lowercase.
id: NonZeroU64The id the post
width: NonZeroU64image width
change: OffsetDateTimeThe time of the last change.
This tracks at least the date of posting and tag edits. This is a unix timestamp.
md5: Md5DigestThe md5 hash of the file.
creator_id: NonZeroU64The creator id.
has_children: boolWhether this has children.
created_at: OffsetDateTimeThe creation date of the post.
status: PostStatusThe status of the post.
source: Option<Box<str>>The original source.
May or may not be a url, it is filled manually by users.
has_notes: boolWhether the post has notes.
has_comments: boolWhether this post has comments.
preview_width: NonZeroU64The preview image width.
preview_height: NonZeroU64The preview image height.