Struct PostListQueryBuilder

pub struct PostListQueryBuilder<'a> {
    pub tags: Option<&'a str>,
    pub pid: Option<u64>,
    pub id: Option<NonZeroU64>,
    pub limit: Option<u16>,
    /* private fields */
}
A builder for post list api queries

Fields

tags: Option<&'a str>

The tags.

pid: Option<u64>

The page #

Starts at 0.

id: Option<NonZeroU64>

The post id.

limit: Option<u16>

The limit.

Implementations

Source

impl<'a> PostListQueryBuilder<'a>

pub fn new(client: &'a Client) -> Self

pub fn tags(&mut self, tags: Option<&'a str>) -> &mut Self

Set the tags to list for.

Querys are based on “tags”. Tags are seperated by spaces, while words are seperated by underscores. Characters are automatically url-encoded.

pub fn pid(&mut self, pid: Option<u64>) -> &mut Self

Set the page number

pub fn id(&mut self, id: Option<NonZeroU64>) -> &mut Self

Set the post id

pub fn limit(&mut self, limit: Option<u16>) -> &mut Self

Set the post limit.

This has a hard upper limit of 1000.

pub fn get_url(&self) -> Result<Url, Error>

Get the api url.

Errors

This fails if:

  1. The generated url is invalid
  2. limit is greater than 1000
pub async fn execute(&self) -> Result<PostList, Error>

Execute the api query and get the results.

Returns

Returns an empty list if there are no results.