Struct TagKind

pub struct TagKind(pub u64);
The tag kind

Tuple Fields

0: u64

Implementations

Source

impl TagKind

pub const GENERAL: Self

The tag represents a generic tag.

pub const AUTHOR: Self

The tag represents the author of the post (the creator of the image, not the uploader).

pub const COPYRIGHT: Self

The tag rperesents the copyright holder of characters in the post.

pub const CHARACTER: Self

The tag represents a character in the post.

pub const METADATA: Self

The tag represents some form of metadata, like the year the post was made.

pub fn is_general(self) -> bool

Returns true if this tag kind is general.

pub fn is_author(self) -> bool

Returns true if this tag kind is an author.

Retruns true if this tag is a copyright.

pub fn is_character(self) -> bool

Returns true if this tag kind is a character.

pub fn is_metadata(self) -> bool

Returns true if this tag kind is a metadata.

pub fn is_unknown(self) -> bool

Returns true if the tag kind is unknown.