pub struct TagKind(pub u64);Expand description
The tag kind
Tuple Fields
0: u64Implementations
Sourceimpl TagKind
impl TagKind
Sourcepub const AUTHOR: Self
pub const AUTHOR: Self
The tag represents the author of the post (the creator of the image, not the uploader).
Sourcepub const METADATA: Self
pub const METADATA: Self
The tag represents some form of metadata, like the year the post was made.
Sourcepub fn is_general(self) -> bool
pub fn is_general(self) -> bool
Returns true if this tag kind is general.
Returns true if this tag kind is an author.
Sourcepub fn is_copyright(self) -> bool
pub fn is_copyright(self) -> bool
Retruns true if this tag is a copyright.
Sourcepub fn is_character(self) -> bool
pub fn is_character(self) -> bool
Returns true if this tag kind is a character.
Sourcepub fn is_metadata(self) -> bool
pub fn is_metadata(self) -> bool
Returns true if this tag kind is a metadata.
Sourcepub fn is_unknown(self) -> bool
pub fn is_unknown(self) -> bool
Returns true if the tag kind is unknown.